#!/usr/bin/ksh
    # kfixer.sh - applies patch to permit safe unload of ITLM Driver
    # returns: 0 - Ok
    #          1 - Fail to stop ITLM agent service 
    #          2 - Fail to unconfigure ITLM driver

    # set LANG for grep on commands
    export LC_ALL=C
    export LC_LANG=en_US

    # init
    AGENT_WAS=UNK
    echo "kfixer.sh - Log" > kfixer.log
    
    # Remove kernel extension load at boot time
    echo "Remove kernel extension load at boot time" >> kfixer.log 2>> kfixer.log 
    odmdelete -o Config_Rules -q rule=/usr/lib/methods/cfgtlmkagent  >> kfixer.log 2>> kfixer.log 

    # Copy safe unconfigure method first and anyway
    echo "Copying new unconfigure method any way" >> kfixer.log 2>> kfixer.log 
    cp ucfgtlmkagent_kfix /usr/lib/methods/ucfgtlmkagent >> kfixer.log 2>> kfixer.log 


    # stop service
    i="." 
    # Service is registred?
    if(lssrc -s tlmagent >> kfixer.log 2>> kfixer.log )
    then 
        echo "ITLM Service is registred" >> kfixer.log 2>> kfixer.log 
	# Service is active?
	if(lssrc -s tlmagent | grep active >> kfixer.log 2>> kfixer.log )
	then AGENT_WAS=STARTED
	     # Send stop
	     echo "ITLM Service is running ... stopping it" >> kfixer.log 2>> kfixer.log 
	     stopsrc -s tlmagent -c >> kfixer.log 2>> kfixer.log   
             # Wait till stop
	     while [ $i != "..............................." ]
	     do if(lssrc -s tlmagent| grep inoperative >> kfixer.log 2>> kfixer.log )
		then echo "ITLM Service is now stopped" >> kfixer.log 2>> kfixer.log 
		     break
		else echo "Waiting for ITLM Service to stop $i" >> kfixer.log 2>> kfixer.log 
		     i=${i}"."
		     sleep 1
		fi
	     done
	else echo "ITLM Service already stopped"  >> kfixer.log 2>> kfixer.log 
	     AGENT_WAS=STOPED
	fi
	
	# Another check
	if(lssrc -s tlmagent | grep inoperative >> kfixer.log 2>> kfixer.log )
	then echo "ITLM Service stop for sure" >> kfixer.log 2>> kfixer.log 
	else echo "ERROR: Failed to stop ITLM service" >> kfixer.log 2>> kfixer.log 
	     exit 1
	fi
    else echo "ITLM Service is not registred" >> kfixer.log 2>> kfixer.log 
	 AGENT_WAS=NA
    fi

    #Unconfigure driver if exists
    if( lsdev -C -l tlmkagent | grep tlmkagent >> kfixer.log 2>> kfixer.log ) 
    then echo "ITLM Driver installed" >> kfixer.log 2>> kfixer.log 
         if (lsdev -C -l tlmkagent | grep Available >> kfixer.log 2>> kfixer.log )
	 then echo "ITLM Driver is Available ... unconfigure" >> kfixer.log 2>> kfixer.log 
	      if (rmdev -l tlmkagent >> kfixer.log 2>> kfixer.log ) 
	      then echo "ITLM Driver unconfigured" >> kfixer.log 2>> kfixer.log 
	      else echo "ERROR: Could not unconfigure ITLM Driver" >> kfixer.log 2>> kfixer.log 
	           exit 2
	      fi
	 fi

         if (lsdev -C -l tlmkagent | grep Defined >> kfixer.log 2>> kfixer.log )
	 then echo "ITLM Driver is now not active" >> kfixer.log 2>> kfixer.log 
	 else echo "ERROR: ITLM Driver is still active" >> kfixer.log 2>> kfixer.log 
	      exit 2
         fi
    else echo "ITLM Driver is not installed" >> kfixer.log 2>> kfixer.log 
    fi

    # restart agent if it was started
    if [ $AGENT_WAS = STARTED ]  
    then echo "ITLM Service was running ... starting it" >> kfixer.log 2>> kfixer.log 
         startsrc -s tlmagent >> kfixer.log 2>> kfixer.log 
    fi
    
